/*create fileref*/
options mprint symbolgen mlogic;
filename qhyq "Q:\My Drive\Matthew\GR paper\File S2. Maize hybrid growth regulator raw data.csv";

data hybrid;
        length UniqID 4 Material $15;
        infile qhyq delimiter=',' firstobs=2 missover;
        input UniqID Material $ Year Loc $ Plot Stand NotLodge EarHt PlantHt DTA DTS ASI Moist Yield
        Treatment $ SampleWt EarLength CobFill KRow Disease Greenleaf1 Greenleaf2 Greenleaf3 Block $ KWt;
run;

*IL14HxP39 was included in the experiment, but was mostly destroyed by wildlife;
*only one plot was measured for yield, but even it was too low for mositure to be measured accurately by combine;
*it was not rated for disease due to the deer damage;
*we will completely drop all data for this hybrid from analysis;
data hybrid;
set hybrid;
if Material ne "IL14HP39" ;
Lodging = (1 - NotLodge)*100;
run; 

%macro Ftests_Means(exp, trait, disease, stand, years, locs);
%if &stand ne stand & &disease ne disease %then %do; title1 "Analysis of &exp &trait" ; %end;
%else %do; title1  "Analysis of &exp &trait with covariate(s): &stand &disease" ; %end;

proc mixed data=&exp;
class Material Year Loc Plot treatment Block;
%if &years > 1 & &locs >1 %then %do;
	model &trait = treatment|material &stand &disease /ddfm=satterth;
	random loc*year block(loc*year) treatment*block(loc*year) treatment*loc*year  material*loc*year treatment*material*loc*year;
	%end;

%else %if &years > 1 & &locs = 1 %then %do;
	model &trait = treatment|material &stand &disease /ddfm=satterth;
	random year block(year) treatment*block(year) treatment*year material*year  treatment*material*year;
	%end;

%else %if &years = 1 & &locs > 1 %then %do;
	model &trait = treatment|material &stand &disease /ddfm=satterth;
	random loc block(loc) treatment*block(loc) treatment*loc material*loc  treatment*material*loc;
	%end;

%else %if &years = 1 & &locs = 1 %then %do;
	model &trait = treatment|material &stand &disease /ddfm=satterth;
	random block treatment*block ;
	%end;

*compute the lsmeans for treatment*material combinations, and get F tests for material effects one each genotype;
lsmeans treatment*material/slice=material pdiff;
ods exclude lsmeans diffs slices;
ods output diffs = difs lsmeans = mns slices = response_p CovParms = vcs Tests3 = Ftests;
run;

*separate the lsmeans into spray and nospray data sets;
data spraymns; set mns; if treatment = "Spray";
rename Estimate = &trait._treat; run;
data nospraymns; set mns; if treatment = "No Spray";
rename Estimate = &trait._untreat; run;

*collect the mean comparisons within Spray treatment;
data spraydifs; set difs; 
if Treatment = "Spray" and _Treatment = "Spray";

*average over the standard errors of all of the comparisons;
proc means data = spraydifs noprint;
var StdErr DF;
output out = meansprayLSD mean = meanSE meanDF;

*compute the LSD(0.05) for entry comparisons within spray treatment;
data meansprayLSD; set meansprayLSD;
t = tinv(0.975, meanDF);
*compute the lsd;
&trait._treat = t*meanSE;
Material = "LSD(0.05)";

*collect the mean comparisons within No-Spray treatment;
data nospraydifs; set difs; 
if Treatment = "No Spray" and _Treatment = "No Spray";

*average over the standard errors of all of the comparisons;
proc means data = nospraydifs noprint;
var StdErr DF;
output out = meannosprayLSD mean = meanSE meanDF;
*compute the LSD(0.05) for entry comparisons within spray treatment;
data meannosprayLSD; set meannosprayLSD;
t = tinv(0.975, meanDF);
*compute the lsd;
&trait._untreat = t*meanSE;
Material = "LSD(0.05)";


*combine the lsmeans with the lsds at bottom and save to a data set;
data entrymns; merge spraymns nospraymns; by material; keep material &trait._treat &trait._untreat;
data lsds; merge meansprayLSD meannosprayLSD; keep material &trait._treat &trait._untreat;

%if &disease = disease %then %do;
data &trait.mns_dis; set entrymns; 
data &trait.lsd_dis; set lsds; run;

*collect the p-values for growth regulator response for each hybrid individually;
data response_p; set response_p; &trait._pval = probF; keep material &trait._pval;
*estimate the response to growth regulator numerically and as a percent of the untreated value
for each hybrid;
data responses; set entrymns; &trait._resp = &trait._treat - &trait._untreat;
	&trait._resp_perc = &trait._resp/&trait._untreat;

proc means data = responses noprint;
var &trait._treat  &trait._untreat &trait._resp &trait._resp_perc; 
output out = &trait._mean_resp mean = &trait._treat &trait._untreat &trait._resp &trait._resp_perc;

data &trait._mean_resp; set &trait._mean_resp; Material = "Mean Response";
keep Material &trait._treat &trait._untreat &trait._resp &trait._resp_perc;

data &trait._resp; merge responses response_p; by material;
%end;
%else; %do;
data &trait.mns; set entrymns; 
data &trait.lsd; set  lsds;  run;
%end;

proc datasets;
delete entrymns lsds meannospray meanspray meannospraylsd meanspraylsd mns nospraydifs nospraymns spraydifs spraymns;

*keep the Ftests and variance components only for analyses without disease covariate;
%if &disease ne disease %then %do;
data &trait._Ftests; set Ftests;
rename DenDF = DenDF_&trait Fvalue = F_&trait ProbF = p_&trait; run;
proc sort; by Effect; 

data &trait._vcs; set vcs;
rename Estimate = Estimate_&trait;
proc sort; by CovParm; 
%end;

%mend;

%Ftests_Means(hybrid, Yield, disease, stand, 2, 3);
%Ftests_Means(hybrid, Yield, , stand, 2, 3);
%Ftests_Means(hybrid, Lodging, disease, , 2, 3);
%Ftests_Means(hybrid, Lodging, , , 2, 3);
%Ftests_Means(hybrid, EarHt, disease, , 2, 3);
%Ftests_Means(hybrid, EarHt, , , 2, 3);
%Ftests_Means(hybrid, PlantHt, disease, , 2, 3);
%Ftests_Means(hybrid, PlantHt, , , 2, 3);
%Ftests_Means(hybrid, DTA, disease, , 2, 1);
%Ftests_Means(hybrid, DTA, , , 2, 1);
%Ftests_Means(hybrid, DTS, disease, , 2, 1);
%Ftests_Means(hybrid, DTS, , , 2, 1);
%Ftests_Means(hybrid, ASI, disease, , 2, 1);
%Ftests_Means(hybrid, ASI, , , 2, 1);
%Ftests_Means(hybrid, Moist, disease, , 2, 3);
%Ftests_Means(hybrid, Moist, , , 2, 3);
%Ftests_Means(hybrid, Greenleaf1, disease, , 2, 3);
%Ftests_Means(hybrid, Greenleaf1, , , 2, 3);
%Ftests_Means(hybrid, Disease, , , 2, 3);
%Ftests_Means(hybrid, CobFill, disease, , 1, 3);
%Ftests_Means(hybrid, CobFill, , , 1, 3);
%Ftests_Means(hybrid, EarLength, disease, , 1, 3);
%Ftests_Means(hybrid, EarLength, , , 1, 3);
%Ftests_Means(hybrid, KRow, disease, , 1, 3);
%Ftests_Means(hybrid, KRow, , , 1, 3);
%Ftests_Means(hybrid, KWt, disease, , 1, 3);
%Ftests_Means(hybrid, KWt, , , 1, 3);
run;

*combine all of the hybrid mean values using disease as covariate;
data hybrid_mns_dis; merge 
Yieldmns_dis Moistmns_dis EarHtmns_dis PlantHtmns_dis DTAmns_dis DTSmns_dis ASImns_dis Lodgingmns_dis Greenleaf1mns_dis CobFillmns_dis EarLengthmns_dis KRowmns_dis KWtmns_dis ;
by Material; run;
data hybrid_lsd_dis; merge Yieldlsd_dis Moistlsd_dis EarHtlsd_dis PlantHtlsd_dis DTAlsd_dis DTSlsd_dis ASIlsd_dis Lodginglsd_dis Greenleaf1lsd_dis CobFilllsd_dis EarLengthlsd_dis KRowlsd_dis KWtlsd_dis;
by Material; run;
data hybrid_mns_dis; set hybrid_mns_dis hybrid_lsd_dis; run;

proc export data = hybrid_mns_dis
outfile = "Q:\My Drive\Matthew\GR paper\File S6. Maize hybrid-treatment means with disease covariate.csv"
replace dbms = CSV; run;

*combine all of the hybrid mean values without disease covariate;
data hybrid_mns; merge Yieldmns Moistmns EarHtmns PlantHtmns DTAmns DTSmns ASImns Lodgingmns Greenleaf1mns CobFillmns EarLengthmns KRowmns KWtmns diseasemns;
by Material; run;
data hybrid_lsd; merge Yieldlsd Moistlsd EarHtlsd PlantHtlsd DTAlsd DTSlsd ASIlsd Lodginglsd Greenleaf1lsd CobFilllsd EarLengthlsd KRowlsd diseaselsd KWtlsd;
by Material; run;
data hybrid_mns; set hybrid_mns hybrid_lsd; run;

proc export data = hybrid_mns
outfile = "Q:\My Drive\Matthew\GR paper\File S7. Maize hybrid-treatment means without disease covariate.csv"
replace dbms = CSV; run;

*combine all of the hybrid responses to growth regulator measured with disease as a covariate;
data hybrid_responses; merge Yield_resp Moist_resp EarHt_resp PlantHt_resp DTA_resp DTS_resp ASI_resp Lodging_resp Greenleaf1_resp CobFill_resp EarLength_resp KRow_resp KWt_resp;
by Material; run;
data hybrid_response_mean; merge Yield_mean_resp Moist_mean_resp Lodging_mean_resp EarHt_mean_resp PlantHt_mean_resp DTA_mean_resp DTS_mean_resp ASI_mean_resp Greenleaf1_mean_resp CobFill_mean_resp EarLength_mean_resp KRow_mean_resp KWt_mean_resp;
by Material; run;
data hybrid_responses; length Material $ 25; set hybrid_responses hybrid_response_mean;

proc export data = hybrid_responses
outfile = "Q:\My Drive\Matthew\GR paper\File S8. Maize hybrid responses to growth regulator with disease covariate.csv"
replace dbms = CSV; run;

*combine all of the hybrid Ftests;
data hybrid_F; merge Yield_Ftests Moist_Ftests EarHt_Ftests PlantHt_Ftests DTA_Ftests DTS_Ftests ASI_Ftests Lodging_Ftests Greenleaf1_Ftests CobFill_Ftests EarLength_Ftests KRow_Ftests KWt_Ftests;
by Effect; run;
proc export data = hybrid_F
outfile = "Q:\My Drive\Matthew\GR paper\File S9. Maize hybrid Fixed effect F-tests raw.csv"
replace dbms = CSV; run;

*combine all of the hybrid variance components;
*this is a bit of a mess because the effects are not consistently named across traits (!);
*but it's close enough that we can output it with 'raw' in the title and fix the output;
data hybrid_vcs; merge Yield_vcs Moist_vcs EarHt_vcs PlantHt_vcs DTA_vcs DTS_vcs ASI_vcs Lodging_vcs Greenleaf1_vcs CobFill_vcs EarLength_vcs KRow_vcs KWt_vcs;
by CovParm; run;
proc export data = hybrid_vcs
outfile = "Q:\My Drive\Matthew\GR paper\File S10. Maize hybrid variance components estimates raw.csv"
replace dbms = CSV; run;
