/*create fileref*/
options mprint symbolgen mlogic;
filename qinq "Q:\My Drive\Matthew\GR paper\File S3. Maize inbred growth regulator raw data.csv";
data inbred;
        infile qinq delimiter=',' firstobs=2 missover;
        input UniqID Material $ Loc $ Plot Stand NotLodge EarHt PlantHt DTS DTA ASI EarCt
                Yield EarLength CobFill KRow Disease Greenleaf1 Greenleaf2 Greenleaf3 Treatment $ Block $ KWt;
run;

data inbred; set inbred;
if Material ne "M141A"; *drop these filler plots;
Lodging = (1 - NotLodge)*100;
if treatment = "NoSpray" then treatment = "No Spray"; *make this consistent with hybrid data set;

%macro Ftests_Means(exp, trait, disease, stand, years, locs);
%if &stand ne stand & &disease ne disease %then %do; title1 "Analysis of &exp &trait" ; %end;
%else %do; title1  "Analysis of &exp &trait with covariate(s): &stand &disease" ; %end;

proc mixed data=&exp;
%if &years > 1 & &locs >1 %then %do;
class Material Year Loc Plot treatment Block;
	model &trait = treatment|material &stand &disease /ddfm=satterth;
	random loc*year block(loc*year) treatment*block(loc*year) treatment*loc*year material*loc*year treatment*material*loc*year;
	%end;

%else %if &years > 1 & &locs = 1 %then %do;
class Material Year Loc Plot treatment Block;
	model &trait = treatment|material &stand &disease /ddfm=satterth;
	random year block(year) treatment*block(year) treatment*year material*year  treatment*material*year;
	%end;

%else %if &years = 1 & &locs > 1 %then %do;
class Material Loc Plot treatment Block;
	model &trait = treatment|material &stand &disease /ddfm=satterth;
	random loc block(loc) treatment*block(loc) treatment*loc material*loc  treatment*material*loc;
	%end;

%else %if &years = 1 & &locs = 1 %then %do;
class Material Plot treatment Block;
	model &trait = treatment|material &stand &disease /ddfm=satterth;
	random block treatment*block ;
	%end;

*compute the lsmeans for treatment*material combinations, and get F tests for material effects one each genotype;
lsmeans treatment*material/slice=material pdiff;
ods exclude lsmeans diffs slices;
ods output diffs = difs lsmeans = mns slices = response_p CovParms = vcs Tests3 = Ftests;
run;

*separate the lsmeans into spray and nospray data sets;
data spraymns; set mns; if treatment = "Spray";
rename Estimate = &trait._treat; run;
data nospraymns; set mns; if treatment = "No Spray";
rename Estimate = &trait._untreat; run;

*collect the mean comparisons within Spray treatment;
data spraydifs; set difs; 
if Treatment = "Spray" and _Treatment = "Spray";

*average over the standard errors of all of the comparisons;
proc means data = spraydifs noprint;
var StdErr DF;
output out = meansprayLSD mean = meanSE meanDF;

*compute the LSD(0.05) for entry comparisons within spray treatment;
data meansprayLSD; set meansprayLSD;
t = tinv(0.975, meanDF);
*compute the lsd;
&trait._treat = t*meanSE;
Material = "LSD(0.05)";

*collect the mean comparisons within No-Spray treatment;
data nospraydifs; set difs; 
if Treatment = "No Spray" and _Treatment = "No Spray";

*average over the standard errors of all of the comparisons;
proc means data = nospraydifs noprint;
var StdErr DF;
output out = meannosprayLSD mean = meanSE meanDF;
*compute the LSD(0.05) for entry comparisons within spray treatment;
data meannosprayLSD; set meannosprayLSD;
t = tinv(0.975, meanDF);
*compute the lsd;
&trait._untreat = t*meanSE;
Material = "LSD(0.05)";

*combine the lsmeans with the lsds at bottom and save to a data set;
data entrymns; merge spraymns nospraymns; by material; keep material &trait._treat &trait._untreat;
data lsds; merge meansprayLSD meannosprayLSD; keep material &trait._treat &trait._untreat;

%if &disease = disease %then %do;
data &trait.mns_dis; set entrymns; 
data &trait.lsd_dis; set lsds; run;

*collect the p-values for growth regulator response for each hybrid individually;
data response_p; set response_p; &trait._pval = probF; keep material &trait._pval;
*estimate the response to growth regulator numerically and as a percent of the untreated value
for each hybrid;
data responses; set entrymns; &trait._resp = &trait._treat - &trait._untreat;
	&trait._resp_perc = &trait._resp/&trait._untreat;

proc means data = responses noprint;
var &trait._treat  &trait._untreat &trait._resp &trait._resp_perc; 
output out = &trait._mean_resp mean = &trait._treat &trait._untreat &trait._resp &trait._resp_perc;

data &trait._mean_resp; set &trait._mean_resp; Material = "Mean Response";
keep Material &trait._treat &trait._untreat &trait._resp &trait._resp_perc;

data &trait._resp; merge responses response_p; by material;
%end;
%else; %do;
data &trait.mns; set entrymns; 
data &trait.lsd; set  lsds;  run;
%end;

proc datasets nolist;
delete entrymns lsds nospraysmn spraymns meannospraylsd meanspraylsd mns nospraydifs nospraymns spraydifs spraymns
responses response_p mean_response;

*keep the Ftests and variance components only for analyses without disease covariate;
%if &disease ne disease %then %do;
data &trait._Ftests; set Ftests;
rename DenDF = DenDF_&trait Fvalue = F_&trait ProbF = p_&trait; run;
proc sort; by Effect; 

data &trait._vcs; set vcs;
rename Estimate = Estimate_&trait;
proc sort; by CovParm; 
%end;

%mend;

%Ftests_Means(inbred, Yield, disease, stand EarCt, 1, 3);
%Ftests_Means(inbred, Yield, , stand EarCt, 1, 3);
%Ftests_Means(inbred, Lodging, disease, , 1, 3);
%Ftests_Means(inbred, Lodging, , , 1, 3);
%Ftests_Means(inbred, EarHt, disease, , 1, 3);
%Ftests_Means(inbred, EarHt, , , 1, 3);
%Ftests_Means(inbred, PlantHt, disease, , 1, 3);
%Ftests_Means(inbred, PlantHt, , , 1, 3);
%Ftests_Means(inbred, DTA, disease, , 1, 1);
%Ftests_Means(inbred, DTA, , , 1, 1);
%Ftests_Means(inbred, DTS, disease, , 1, 1);
%Ftests_Means(inbred, DTS, , , 1, 1);
%Ftests_Means(inbred, ASI, disease, , 1, 1);
%Ftests_Means(inbred, ASI, , , 1, 1);
%Ftests_Means(inbred, Greenleaf1, disease, , 1, 3);
%Ftests_Means(inbred, Greenleaf1, , , 1, 3);
%Ftests_Means(inbred, Disease, , , 1, 3);
%Ftests_Means(inbred, CobFill, disease, , 1, 3);
%Ftests_Means(inbred, CobFill, , , 1, 3);
%Ftests_Means(inbred, EarLength, disease, , 1, 3);
%Ftests_Means(inbred, EarLength, , , 1, 3);
%Ftests_Means(inbred, KRow, disease, , 1, 3);
%Ftests_Means(inbred, KRow, , , 1, 3);
%Ftests_Means(inbred, KWt, disease, , 1, 3);
%Ftests_Means(inbred, KWt, , , 1, 3);
run;

*combine all of the inbred mean values using disease as covariate;
data inbred_mns_dis; merge Yieldmns_dis Lodgingmns_dis EarHtmns_dis PlantHtmns_dis DTAmns_dis DTSmns_dis ASImns_dis Greenleaf1mns_dis CobFillmns_dis EarLengthmns_dis KRowmns_dis KWtmns_dis ;
by Material; run;
data inbred_lsd_dis; merge Yieldlsd_dis Lodginglsd_dis EarHtlsd_dis PlantHtlsd_dis DTAlsd_dis DTSlsd_dis ASIlsd_dis Greenleaf1lsd_dis CobFilllsd_dis EarLengthlsd_dis KRowlsd_dis KWtlsd_dis;
by Material; run;
data inbred_mns_dis; length Material $ 25; set inbred_mns_dis inbred_lsd_dis; run;

proc export data = inbred_mns_dis
outfile = "Q:\My Drive\Matthew\GR paper\File S11. Maize inbred-treatment means with disease covariate.csv"
replace dbms = CSV; run;

*combine all of the inbred mean values without disease covariate;
data inbred_mns; merge Yieldmns Lodgingmns EarHtmns PlantHtmns DTAmns DTSmns ASImns Greenleaf1mns CobFillmns EarLengthmns KRowmns KWtmns diseasemns;
by Material; run;
data inbred_lsd; merge Yieldlsd Lodginglsd EarHtlsd PlantHtlsd DTAlsd DTSlsd ASIlsd  Greenleaf1lsd CobFilllsd EarLengthlsd KRowlsd KWtlsd diseaselsd;
by Material; run;
data inbred_mns; length Material $ 25; set inbred_mns inbred_lsd; run;

proc export data = inbred_mns 
outfile = "Q:\My Drive\Matthew\GR paper\File S12. Maize inbred-treatment means without disease covariate.csv"
replace dbms = CSV; run;

*combine all of the hybrid responses to growth regulator measured with disease as a covariate;
data inbred_responses; merge Yield_resp Lodging_resp EarHt_resp PlantHt_resp DTA_resp DTS_resp ASI_resp  Greenleaf1_resp CobFill_resp EarLength_resp KRow_resp KWt_resp;
by Material; run;
data inbred_response_mean; merge Yield_mean_resp Lodging_mean_resp EarHt_mean_resp PlantHt_mean_resp DTA_mean_resp DTS_mean_resp ASI_mean_resp Greenleaf1_mean_resp CobFill_mean_resp EarLength_mean_resp KRow_mean_resp KWt_mean_resp;
by Material; run;
data inbred_responses; length Material $ 25; set inbred_responses inbred_response_mean;

proc export data = inbred_responses
outfile = "Q:\My Drive\Matthew\GR paper\File S13. Maize inbred responses to growth regulator with disease covariate.csv"
replace dbms = CSV; run;


*combine all of the hybrid Ftests;
data hybrid_F; merge Yield_Ftests Lodging_Ftests EarHt_Ftests PlantHt_Ftests DTA_Ftests DTS_Ftests ASI_Ftests  Greenleaf1_Ftests CobFill_Ftests EarLength_Ftests KRow_Ftests KWt_Ftests;
by Effect; run;
proc export data = hybrid_F
outfile = "Q:\My Drive\Matthew\GR paper\File S14. Maize inbred Fixed effect F-tests raw.csv"
replace dbms = CSV; run;

*combine all of the hybrid variance components;
*this is a bit of a mess because the effects are not consistently named across traits (!);
*but it's close enough that we can output it with 'raw' in the title and fix the output;
data hybrid_vcs; merge Yield_vcs Lodging_vcs EarHt_vcs PlantHt_vcs DTA_vcs DTS_vcs ASI_vcs Greenleaf1_vcs CobFill_vcs EarLength_vcs KRow_vcs KWt_vcs;
by CovParm; run;
proc export data = hybrid_vcs
outfile = "Q:\My Drive\Matthew\GR paper\File S15. Maize inbred variance components estimates raw.csv"
replace dbms = CSV; run;



